=== modified file 'lib/common/db.py'
--- lib/common/db.py	2008-02-15 03:58:06 +0000
+++ lib/common/db.py	2008-02-15 04:45:12 +0000
@@ -281,8 +281,9 @@
         # Make a copy of the dict. Change password to passhash (hashing it),
         # and set 'state' to "no_agreement".
         kwargs = copy.copy(kwargs)
-        kwargs['passhash'] = _passhash(kwargs['password'])
-        del kwargs['password']
+        if 'password' in kwargs:
+            kwargs['passhash'] = _passhash(kwargs['password'])
+            del kwargs['password']
         kwargs['state'] = "no_agreement"
         # Execute the query.
         return self.insert(kwargs, "login", self.login_fields, dry=dry)

=== modified file 'lib/common/makeuser.py'
--- lib/common/makeuser.py	2008-02-15 04:11:15 +0000
+++ lib/common/makeuser.py	2008-02-15 04:45:12 +0000
@@ -237,19 +237,15 @@
     if errors:
         raise Exception, errors
 
-def make_user_db(login, password, uid, email, nick, fullname, rolenm,
-    studentid, force=True):
+def make_user_db(**kwargs):
     """Creates a user's entry in the database, filling in all the fields.
-    If force is False, throws an exception if the user already exists.
-    If True, overwrites the user's entry in the DB.
+    All arguments must be keyword args. They are the fields in the table.
+    However, instead of supplying a "passhash", you must supply a
+    "password" argument, which will be hashed internally.
+    Also do not supply a state. All users are created in the "no_agreement"
+    state.
+    Throws an exception if the user already exists.
     """
     dbconn = db.DB()
-    if force:
-        # Delete user if it exists
-        try:
-            dbconn.delete_user(login)
-        except:
-            pass
-    dbconn.create_user(login, password, uid, email, nick, fullname, rolenm,
-        studentid)
+    dbconn.create_user(**kwargs)
     dbconn.close()

=== modified file 'makeuser.py'
--- makeuser.py	2008-02-14 05:58:03 +0000
+++ makeuser.py	2008-02-15 04:45:12 +0000
@@ -31,51 +31,77 @@
 import os
 import os.path
 import pwd
+import getopt
 # Import modules from the website is tricky since they're in the www
 # directory.
 sys.path.append(os.path.join(os.getcwd(), 'www'))
 import conf
-import common.makeuser
-
-if len(sys.argv) <= 6:
-    print "Usage: python makeuser.py <username> <password> <email> " \
-        "<nick> <fullname> <rolenm> [<studentid>]"
-    sys.exit()
+import common.makeuser, common.db
+
+# Requireds and optionals will be used to display the usage message
+# AND do argument processing
+# The names here must correspond to the fields in the database.
+requireds = ["login", "fullname", "rolenm"]
+optionals = [
+    ('p', 'password', "Cleartext password for this user"),
+    ('n', 'nick', "Display name (defaults to <fullname>)"),
+    ('e', 'email', "Email address"),
+    ('s', 'studentid', "Student ID"),
+]
+
+if len(sys.argv) <= 3:
+    # Nicely format the usage message using the optionals
+    print ("Usage: python makeuser.py [OPTIONS] %s\n    OPTIONS"
+        % ' '.join(['<%s>' % x for x in requireds]))
+    for short, long, desc in optionals:
+        t = "        -%s | --%s" % (short, long)
+        print t + (' ' * max(28 - len(t), 2)) + desc
+    sys.exit(1)
 
 if os.getuid() != 0:
     print "Must run makeuser.py as root."
-    sys.exit()
-
-username = sys.argv[1]
-password = sys.argv[2]
-email = sys.argv[3]
-nick = sys.argv[4]
-fullname = sys.argv[5]
-rolenm = sys.argv[6]
-if len(sys.argv) > 7:
-    studentid = sys.argv[7]
-else:
-    studentid = None
-
-try:
+    sys.exit(1)
+
+shorts = ''.join([o[0] + ":" for o in optionals])
+longs = [o[1] + "=" for o in optionals]
+opts, args = getopt.gnu_getopt(sys.argv[1:], shorts, longs)
+opts = dict(opts)
+
+# Get the dictionary of fields from opts and args
+dict = {}
+for i in range(0, len(requireds)):
+    dict[requireds[i]] = args[i]
+for short, long, _ in optionals:
+    try:
+        dict[long] = opts['-' + short]
+    except KeyError:
+        try:
+            dict[long] = opts['--' + long]
+        except KeyError:
+            pass
+login = dict['login']
+if 'nick' not in dict:
+    dict['nick'] = dict['fullname']
+
+if True:
     # Resolve the user's username into a UID
     # Create the user if it does not exist
     try:
-        (_,_,uid,_,_,_,_) = pwd.getpwnam(username)
+        (_,_,uid,_,_,_,_) = pwd.getpwnam(login)
     except KeyError:
-        if os.system("useradd '%s'" % username) != 0:
+        if os.system("useradd '%s'" % login) != 0:
             raise Exception("Failed to add Unix user account")
         try:
-            (_,_,uid,_,_,_,_) = pwd.getpwnam(username)
+            (_,_,uid,_,_,_,_) = pwd.getpwnam(login)
         except KeyError:
             raise Exception("Failed to add Unix user account")
+    dict['unixid'] = uid
     # Make the user's jail
-    common.makeuser.make_jail(username, uid)
+    common.makeuser.make_jail(login, uid)
     # Make the user's database entry
-    common.makeuser.make_user_db(username, password, uid, email, nick,
-        fullname, rolenm, studentid)
-except Exception, message:
-    print "Error: " + str(message)
-    sys.exit(1)
+    common.makeuser.make_user_db(**dict)
+#except Exception, message:
+#    print "Error: " + str(message)
+#    sys.exit(1)
 
-print "Successfully created user %s (%s)." % (username, fullname)
+print "Successfully created user %s (%s)." % (login, dict['fullname'])

